@@ -8,4 +8,9 @@ describe('is-potential-custom-element-name', function() {
 		assert.equal(isPotentialCustomElementName('baz-©'), false);
 		assert.equal(isPotentialCustomElementName('annotation-xml'), true);
 	});
+
+	it('avoids excess backtracking', function() {
+		const longA = 'a'.repeat(20000000);
+		assert.strictEqual(isPotentialCustomElementName('a-'.concat(longA)), true);
+	})
 });
